Document

Exhibit 99.2
THE CLOROX COMPANY
RECONCILIATION OF ECONOMIC PROFIT (UNAUDITED) (1)

Dollars in millions |  | FY22 |  | FY21 |  | FY20
Earnings before income taxes |  | $ | 607 |  |  | $ | 900 |  |  | $ | 1,185 |
Add back: |  |  |  |  |  |
Certain U.S. GAAP charges (2)(3) |  | 61 |  |  | 357 |  |  | 2 |
Interest expense |  | 106 |  |  | 99 |  |  | 99 |
Less: |  |  |  |  |  |
Saudi JV acquisition gain (4) |  | — |  |  | (82) |  |  | — |
Earnings before income taxes, certain U.S. GAAP items and interest expense |  | 774 |  |  | 1,274 |  |  | 1,286 |
Less: |  |  |  |  |  |
Income taxes on earnings before income taxes, certain U.S. GAAP items and interest expense (5) |  | 174 |  |  | 264 |  |  | 267 |
Adjusted after tax profit |  | 600 |  |  | 1,010 |  |  | 1,019 |
Less: After tax profit attributable to noncontrolling interests |  | 9 |  |  | 9 |  |  | — |
Adjusted after tax profit attributable to Clorox |  | 591 |  |  | 1,001 |  |  | 1,019 |
Average capital employed (6) |  | 3,428 |  |  | 3,655 |  |  | 3,478 |
Less: Capital charge (7) |  | 309 |  |  | 329 |  |  | 313 |
Economic profit (1) (Adjusted after tax profit attributable to Clorox less capital charge) |  | $ | 282 |  |  | $ | 672 |  |  | $ | 706 |

(1) Economic profit (EP) is defined by the Company as earnings before income taxes, excluding certain U.S. GAAP items (such as asset impairments, charges related to digital capabilities and productivity enhancements investment, significant losses/(gains) related to acquisitions and other non-recurring or unusual items) and interest expense; less income taxes (calculated based on the Company’s effective tax rate excluding the identified U.S. GAAP items), and less after tax profit attributable to noncontrolling interests, and less a capital charge (calculated as average capital employed multiplied by a cost of capital rate). EP is a key financial metric that the Company’s management uses to evaluate business performance and allocate resources, and is a component in determining employee incentive compensation. The Company’s management believes EP provides additional perspective to investors about financial returns generated by the business and represents profit generated over and above the cost of capital used by the business to generate that profit
(2) Fiscal year 2022 includes $61 ($47 after tax) of incremental operating expenses primarily recorded within selling and administrative expenses related to the implementation related to the Company's digital capabilities and productivity enhancements investment, which are recorded within the Corporate segment. The expenses relate to the following:

|  |  | Twelve Months Ended |  |
|  |  | June 30, 2022 |  |
|  | External consulting fees (a) | $ | 43 |  |  |
|  | IT project personnel costs (b) | 11 |  |  |
|  | Other (c) | 7 |  |  |
|  | Total | $ | 61 |  |  |
|  | (a) Comprised of third-party consulting fees incurred to assist in the project management and the preliminary project stage of this transformative investment. The company relies on consultants for certain capabilities required for these programs that the company does not maintain internally. These costs support the implementation of these programs incremental to the company's normal IT costs and will not be incurred following implementation.
|  | (b) Comprised of labor costs associated with internal IT project management teams that are utilized to oversee the new system implementations. Given the magnitude and transformative nature of the implementations planned, the necessary project management costs are incremental to the historical levels of spend and will no longer be incurred subsequent to implementation. As a result of this long-term strategic investment, the company considers these costs not reflective of the ongoing costs to operate its business.
|  | (c) Comprised of various other expenses associated with the company’s new system implementations, including company personnel dedicated to the project that have been backfilled with either permanent or temporary resources in positions that are considered part of normal operating expenses.

(3) Fiscal year 2021 includes impairment charges of $329 (after tax $267) of which $228, $93, and $8 related to the goodwill of the Vitamins, Minerals and Supplements (VMS) business, certain indefinite-lived trademarks and other assets, respectively, and non-cash charges of $28 ($21 after tax) on investments and related arrangements made with a Professional Products business supplier.
(4) On July 9, 2020, the Company increased its investment in each of the two entities comprising its joint venture in the Kingdom of Saudi Arabia (Saudi joint venture). As a result of this transaction, a non-cash nonrecurring net gain was recognized of $82 ($76 after tax) in Other (income) expense, net in the quarter ended September 30, 2020, primarily due to the remeasurement of the carrying value of the company’s previously held equity investment to fair value.

(5) The tax rate applied is the effective tax rate before the identified U.S. GAAP items was 22.5%, 20.7% and 20.8% in fiscal years 2022, 2021, and 2020, respectively. The difference between the fiscal year 2022 effective tax rate on earnings of 22.4% is due to the tax rate impact of the incremental operating expenses recorded related to the implementation of the Company’s digital capabilities and productivity enhancements investment of 0.1%. The difference between the fiscal year 2021 effective tax rate on earnings of 20.1% is due to the tax rate impact of the Professional Products supplier charge, VMS impairment, and Saudi JV acquisition gain of 0.1%, (0.4)%, and 0.9%, respectively.
(6) Total capital employed represents total assets less non-interest bearing liabilities. Adjusted capital employed represents total capital employed adjusted to add back current year after tax U.S. GAAP items, as applicable, and deduct the current year after tax non-cash, non-recurring gain. Average capital employed is the average of adjusted capital employed for the current year and total capital employed for the prior year, based on year-end balances. See below for details of the average capital employed calculation.
(7) Capital charge represents average capital employed multiplied by a cost of capital, which was 9% for all fiscal years presented. The calculation of capital charge includes the impact of rounding numbers.

Dollars in millions |  | FY22 |  | FY21 |  | FY20
Total assets |  | $ | 6,158 |  |  | $ | 6,334 |  |  | $ | 6,213 |
Less: |  |  |  |  |  |
Accounts payable and accrued liabilities (8) |  | 1,463 |  |  | 1,670 |  |  | 1,327 |
Current operating lease liabilities |  | 78 |  |  | 81 |  |  | 64 |
Income taxes payable |  | — |  |  | — |  |  | 25 |
Long-term operating lease liabilities |  | 314 |  |  | 301 |  |  | 278 |
Other liabilities (8) |  | 778 |  |  | 819 |  |  | 755 |
Deferred income taxes |  | 66 |  |  | 67 |  |  | 62 |
Non-interest bearing liabilities |  | 2,699 |  |  | 2,938 |  |  | 2,511 |
Total capital employed (6) |  | 3,459 |  |  | 3,396 |  |  | 3,702 |
After tax certain U.S. GAAP items(3)(4) |  | 0 |  | 212 |  | 2
Adjusted capital employed (6) |  | $ | 3,459 |  |  | $ | 3,608 |  |  | $ | 3,704 |
Average capital employed |  | $ | 3,428 |  |  | $ | 3,655 |  |  | $ | 3,478 |

(8) Accounts payable and accrued liabilities and Other liabilities are adjusted to exclude interest-bearing liabilities.